import * as i0 from '@angular/core';
import { Directive, Input, HostListener, NgModule } from '@angular/core';

class InputNumberDirective {
    constructor(el) {
        this.el = el;
        // allow decimal numbers with up to 2 decimal places
        this.decimalRegex = new RegExp(/^-?[0-9]+(\.[0-9]*){0,1}$/g);
        // Allow key codes for special events. Reflect :
        // Backspace, tab, end, home
        this.specialKeys = ['Backspace', 'Tab', 'Escape', 'End', 'Enter', 'Home', 'ArrowLeft', 'ArrowRight', 'Del', 'Delete', 'Clear', 'Copy', 'Paste', '-'];
        this.limitDecimalPlaces = 0;
        this.disableCopy = false;
        this.disablePaste = false;
        this.allowNegative = false;
        this.min = -Infinity;
        this.max = Infinity;
        this.regex = null;
        this.inputElement = el.nativeElement;
    }
    /**
     * If the min or max input changes, then set the min or max property to the new value, or to -Infinity
     * or Infinity if the new value is not a number
     * @param {SimpleChanges} changes - SimpleChanges
     */
    ngOnChanges(changes) {
        if (changes['min']) {
            this.min = isNaN(Number(this.min)) ? -Infinity : Number(this.min);
        }
        if (changes['max']) {
            this.max = isNaN(Number(this.max)) ? Infinity : Number(this.max);
        }
    }
    /* Preventing the user from entering anything other than a number. */
    onBeforeInput(event) {
        if (isNaN(Number(event.data))) {
            /* This is to allow the user to enter a decimal point. */
            if ((Boolean(this.limitDecimalPlaces) && event.data === '.') || (Boolean(this.allowNegative) && event.data === '-'))
                return;
            event.preventDefault();
            event.stopPropagation();
        }
    }
    /* Allowing the user to use the keyboard to navigate the input field. */
    onKeyDown(event) {
        // Allow Backspace, tab, end, and home keys
        if (this.specialKeys.indexOf(event.key) !== -1) {
            return;
        }
        let current = this.el.nativeElement.value;
        let next = current.concat(event.key);
        /* This is to prevent the user from entering a number that is greater than the max or less than the min. */
        if (next && Boolean(this.limitDecimalPlaces) && !String(next).match(this.decimalRegex)) {
            event.preventDefault();
        }
        const newNumber = Number(next);
        /* Preventing the user from entering a number that is greater than the max or less than the min. */
        if (newNumber > this.max || newNumber < this.min) {
            event.preventDefault();
        }
    }
    /* Preventing the user from copying the input value. */
    onCopy(event) {
        if (Boolean(this.disableCopy))
            event.preventDefault();
    }
    /* Preventing the user from pasting the input value. */
    onPaste(event) {
        if (Boolean(this.disablePaste))
            event.preventDefault();
    }
    /* Limiting the number of decimal places. */
    onInput(event) {
        const input = event.target;
        const value = input.value;
        // If the value contains more decimal places than allowed, truncate it
        if (Boolean(this.limitDecimalPlaces) && value.indexOf('.') !== -1 && value.split('.')[1].length > this.limitDecimalPlaces) {
            input.value = value.substring(0, value.indexOf('.') + this.limitDecimalPlaces + 1);
        }
        /* This is to prevent the user from entering more than one negative sign. */
        if (Boolean(this.allowNegative) && value.indexOf('-') !== -1 && value.split('-').length !== 2) {
            input.value = value.substring(0, 1);
        }
    }
}
InputNumberDirective.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "15.0.4", ngImport: i0, type: InputNumberDirective, deps: [{ token: i0.ElementRef }], target: i0.ɵɵFactoryTarget.Directive });
InputNumberDirective.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "15.0.4", type: InputNumberDirective, selector: "[inputNumberValidator]", inputs: { limitDecimalPlaces: "limitDecimalPlaces", disableCopy: "disableCopy", disablePaste: "disablePaste", allowNegative: "allowNegative", min: "min", max: "max", pattern: "pattern" }, host: { listeners: { "beforeinput": "onBeforeInput($event)", "keydown": "onKeyDown($event)", "copy": "onCopy($event)", "paste": "onPaste($event)", "input": "onInput($event)" } }, usesOnChanges: true, ngImport: i0 });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "15.0.4", ngImport: i0, type: InputNumberDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: '[inputNumberValidator]',
                }]
        }], ctorParameters: function () { return [{ type: i0.ElementRef }]; }, propDecorators: { limitDecimalPlaces: [{
                type: Input
            }], disableCopy: [{
                type: Input
            }], disablePaste: [{
                type: Input
            }], allowNegative: [{
                type: Input
            }], min: [{
                type: Input
            }], max: [{
                type: Input
            }], pattern: [{
                type: Input
            }], onBeforeInput: [{
                type: HostListener,
                args: ['beforeinput', ['$event']]
            }], onKeyDown: [{
                type: HostListener,
                args: ['keydown', ['$event']]
            }], onCopy: [{
                type: HostListener,
                args: ['copy', ['$event']]
            }], onPaste: [{
                type: HostListener,
                args: ['paste', ['$event']]
            }], onInput: [{
                type: HostListener,
                args: ['input', ['$event']]
            }] } });

class InputValidatorsModule {
}
InputValidatorsModule.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "15.0.4", ngImport: i0, type: InputValidatorsModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule });
InputValidatorsModule.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "15.0.4", ngImport: i0, type: InputValidatorsModule, declarations: [InputNumberDirective], exports: [InputNumberDirective] });
InputValidatorsModule.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "15.0.4", ngImport: i0, type: InputValidatorsModule });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "15.0.4", ngImport: i0, type: InputValidatorsModule, decorators: [{
            type: NgModule,
            args: [{
                    declarations: [
                        InputNumberDirective
                    ],
                    imports: [],
                    exports: [
                        InputNumberDirective
                    ]
                }]
        }] });

/*
 * Public API Surface of input-validators
 */

/**
 * Generated bundle index. Do not edit.
 */

export { InputNumberDirective, InputValidatorsModule };
//# sourceMappingURL=goodbetterbist-input-validators.mjs.map
//# sourceMappingURL=goodbetterbist-input-validators.mjs.map
